@@ -192,8 +192,6 @@ def setup():
             if response.get("success"):
                 click.echo("Test notification sent successfully!")
                 click.echo("Check your Apple Watch for the notification.")
-            elif response.get("queued"):
-                click.echo("Network error: Test notification queued for later delivery.")
             else:
                 click.echo(f"Error: {response.get('error', 'Unknown error')}")
         except Exception as e:
@@ -297,9 +295,6 @@ def test():
         if response.get("success"):
             click.echo("Test notification sent successfully!")
             click.echo("Check your Apple Watch for the notification.")
-        elif response.get("queued"):
-            click.echo("Network error: Test notification queued for later delivery.")
-            click.echo("Run 'watchcode flush' when online to send queued notifications.")
         else:
             click.echo(f"Error: {response.get('error', 'Unknown error')}", err=True)
             sys.exit(1)
@@ -373,7 +368,7 @@ def notify(event: str, requires_action: bool, message_opt: Optional[str], notifi
         )
 
         # Don't print anything on success (hooks should be silent)
-        if not response.get("success") and not response.get("queued"):
+        if not response.get("success"):
             # Only log errors to stderr
             click.echo(f"WatchCode error: {response.get('error')}", err=True)
 
@@ -404,15 +399,6 @@ def status():
 
     click.echo()
 
-    # Queue status
-    queue = config.load_queue()
-    click.echo(f"Queued notifications: {len(queue)}")
-
-    if queue:
-        click.echo("Run 'watchcode flush' to send queued notifications.")
-
-    click.echo()
-
     # Hook status
     hook_status = installer.get_hook_status()
     click.echo("Installed hooks:")
@@ -494,40 +480,6 @@ def devices(clear: bool, verify: bool, yes: bool):
     click.echo("Use --clear to unregister and remove configuration.")
 
 
-@main.command()
-def flush():
-    """Send queued offline notifications."""
-    config = Config()
-
-    if not config.is_configured():
-        click.echo("WatchCode not configured. Run 'watchcode setup' first.", err=True)
-        sys.exit(1)
-
-    queue = config.load_queue()
-    if not queue:
-        click.echo("No queued notifications.")
-        return
-
-    click.echo(f"Flushing {len(queue)} queued notification(s)...")
-
-    try:
-        client = RelayClient(config)
-        result = client.flush_queue()
-
-        click.echo()
-        click.echo(f"Sent: {result['sent']}/{result['total']}")
-
-        if result['failed'] > 0:
-            click.echo(f"Failed: {result['failed']}/{result['total']}")
-            click.echo("Failed notifications remain queued.")
-        else:
-            click.echo("All notifications sent successfully!")
-
-    except Exception as e:
-        click.echo(f"Error: {str(e)}", err=True)
-        sys.exit(1)
-
-
 @main.command("update-scripts")
 def update_scripts():
     """Update hook scripts in ~/.watchcode/ to latest version."""
