@@ -158,14 +158,17 @@ def type_and_submit(text: str) -> bool:
 
 
 def inject_keystroke(text: str) -> bool:
-    """Inject text into terminal via detached subprocess.
+    """Inject text into Terminal.app via detached subprocess.
 
     Uses a completely detached process (start_new_session=True) that runs AFTER
     the hook exits. This bypasses the WindowServer access issue that prevents
     osascript from working in hook subprocess context.
 
+    Targets Terminal.app specifically and uses base64 encoding to handle
+    special characters safely.
+
     Args:
-        text: The text to type (usually a single character like "1", "2", etc.)
+        text: The text to type (can be any string including special chars)
 
     Returns:
         True if the detached process was launched, False on error.
@@ -177,14 +180,27 @@ def inject_keystroke(text: str) -> bool:
     log_debug(f"Scheduling keystroke injection: '{text}'")
 
     try:
+        import base64
+        # Base64 encode the text to safely pass through bash
+        encoded_text = base64.b64encode(text.encode('utf-8')).decode('ascii')
+
         # Build the bash script that runs AFTER this hook exits
-        # Uses a small delay to ensure terminal is ready
+        # Uses base64 decoding for safe text handling
+        # Targets Terminal.app specifically for reliable focus
         script = f'''
 sleep 0.3
-echo -n '{text}' | pbcopy
-osascript -e 'tell application "System Events" to keystroke "v" using command down' 2>/dev/null
-sleep 0.1
-osascript -e 'tell application "System Events" to key code 36' 2>/dev/null
+echo "{encoded_text}" | base64 -d | pbcopy
+osascript <<'APPLESCRIPT'
+tell application "Terminal"
+    activate
+    delay 0.15
+    tell application "System Events"
+        keystroke "v" using command down
+        delay 0.1
+        key code 36
+    end tell
+end tell
+APPLESCRIPT
 '''
 
         # Launch completely detached subprocess
@@ -688,8 +704,14 @@ def handle_notification(data: dict) -> int:
         elif action == 'always_allow':
             output_decision('allow')  # JSON doesn't have "always allow" option
             log_debug(f"[seq={sequence_id}] User set ALWAYS ALLOW via Watch")
+        else:
+            log_debug(f"[seq={sequence_id}] Unknown action '{action}', no decision output")
+            # Send invalidation - unknown action
+            send_invalidation(notification_id, 'unknown_action')
     else:
         log_debug(f"[seq={sequence_id}] No response, falling back to terminal")
+        # Send invalidation so Watch knows user will respond via terminal
+        send_invalidation(notification_id, 'terminal_fallback')
 
     return 0
 
@@ -903,6 +925,58 @@ def check_relay_response(notification_id: str) -> dict | None:
     return None
 
 
+def send_invalidation(notification_id: str, reason: str = 'terminal_response') -> bool:
+    """Send invalidation to relay server to dismiss Watch notification.
+
+    Called when user responds via terminal instead of Watch.
+    This sends a silent push to Watch to mark the request as handled.
+
+    Args:
+        notification_id: The notification ID to invalidate
+        reason: Reason for invalidation (default: 'terminal_response')
+
+    Returns:
+        True if successful, False otherwise.
+    """
+    auth_token = get_auth_token()
+    if not auth_token:
+        log_debug("No auth token found for invalidation")
+        return False
+
+    if not notification_id:
+        log_debug("No notification_id for invalidation")
+        return False
+
+    url = f"{RELAY_URL}/invalidate"
+    payload = {
+        'auth_token': auth_token,
+        'notification_id': notification_id,
+        'reason': reason
+    }
+
+    try:
+        import urllib.request
+        import urllib.error
+
+        data = json.dumps(payload).encode('utf-8')
+        req = urllib.request.Request(url, data=data, method='POST')
+        req.add_header('Content-Type', 'application/json')
+
+        with urllib.request.urlopen(req, timeout=5) as resp:
+            if resp.status == 200:
+                log_debug(f"✓ Invalidation sent for {notification_id[:8]}...")
+                return True
+            else:
+                log_debug(f"Invalidation failed: status {resp.status}")
+                return False
+    except urllib.error.HTTPError as e:
+        log_debug(f"Invalidation HTTP error: {e.code}")
+        return False
+    except Exception as e:
+        log_debug(f"Invalidation error: {e}")
+        return False
+
+
 def delete_stale_cloudkit_record(session_id: str) -> None:
     """Delete a stale CloudKit record to prevent future false positives."""
     if not CLOUDKIT_POLLER.exists():
@@ -1160,10 +1234,10 @@ def handle_permission_request(data: dict) -> int:
     cwd = data.get('cwd', '')
     project_name = Path(cwd).name if cwd else 'Unknown'
 
-    # Skip AskUserQuestion - handled by PreToolUse hook with non-blocking background responder
+    # Handle AskUserQuestion specially - send question with options to Watch
     if tool_name == 'AskUserQuestion':
-        log_debug(f"AskUserQuestion in PermissionRequest - skipping (handled by PreToolUse)")
-        return 0  # Don't block, let PreToolUse handle it
+        log_debug(f"AskUserQuestion in PermissionRequest - handling with question options")
+        return handle_ask_user_question(tool_input, session_id, project_name)
 
     log_debug(f"PermissionRequest: tool={tool_name}, session={session_id}")
 
@@ -1236,9 +1310,13 @@ def handle_permission_request(data: dict) -> int:
         else:
             log_debug(f"[seq={sequence_id}] Unknown action '{action}', no decision output")
             # No output = terminal prompt stays active
+            # Send invalidation so Watch knows to dismiss this request
+            send_invalidation(notification_id, 'unknown_action')
     else:
         log_debug(f"[seq={sequence_id}] No response received, falling back to terminal prompt")
         # No output = terminal prompt stays active
+        # Send invalidation so Watch knows user will respond via terminal
+        send_invalidation(notification_id, 'terminal_fallback')
 
     return 0
 
@@ -1306,24 +1384,43 @@ def handle_ask_user_question(tool_input: dict, session_id: str, project_name: st
 
         # For selectOption action, map selected label to option number
         if action == 'selectOption' and selected_options:
-            # Map first selected option to its 1-based index
             selected_label = selected_options[0]
-            option_number = None
-            for idx, opt in enumerate(options, 1):
-                if opt.get('label') == selected_label:
-                    option_number = str(idx)
-                    break
 
-            if option_number:
-                log_debug(f"Mapped '{selected_label}' → option {option_number}")
-                inject_keystroke(option_number)
+            # Handle custom/voice input (Watch sends "__custom__" with message)
+            if selected_label == '__custom__':
+                custom_text = response.get('message', '')
+                if custom_text:
+                    log_debug(f"Custom text from Watch: '{custom_text}'")
+                    # Use inject_keystroke (detached subprocess) for reliable paste
+                    inject_keystroke(custom_text)
+                else:
+                    log_debug(f"⚠️ __custom__ selected but no message text received")
+                    # Send invalidation - custom input failed
+                    send_invalidation(notification_id, 'custom_input_failed')
             else:
-                log_debug(f"⚠️ Could not map '{selected_label}' to option number")
+                # Map predefined option to its 1-based index
+                option_number = None
+                for idx, opt in enumerate(options, 1):
+                    if opt.get('label') == selected_label:
+                        option_number = str(idx)
+                        break
+
+                if option_number:
+                    log_debug(f"Mapped '{selected_label}' → option {option_number}")
+                    inject_keystroke(option_number)
+                else:
+                    log_debug(f"⚠️ Could not map '{selected_label}' to option number")
+                    # Send invalidation - mapping failed
+                    send_invalidation(notification_id, 'option_mapping_failed')
         else:
             # Fallback to action as answer
             log_debug(f"Fallback to action: {action}")
+            # Send invalidation - unexpected action
+            send_invalidation(notification_id, 'unexpected_action')
     else:
         log_debug(f"No Watch response, falling back to terminal prompt")
+        # Send invalidation so Watch knows user will respond via terminal
+        send_invalidation(notification_id, 'terminal_fallback')
 
     return 0
 
@@ -1387,71 +1484,22 @@ def send_question_to_relay(
 
 
 def handle_pre_tool_use(data: dict) -> int:
-    """Handle 'pre_tool_use' hook - detect AskUserQuestion and send to Watch.
+    """Handle 'pre_tool_use' hook.
 
-    When Claude asks a multi-choice question, this sends a notification
-    showing the question and options. User can select on Watch.
+    NOTE: AskUserQuestion is now handled by handle_ask_user_question (called from
+    handle_permission_request). Processing it here too would cause DOUBLE INPUT
+    because both hooks fire for the same question.
+
+    This hook is currently a no-op but kept for future pre-tool-use needs.
     """
     tool_name = data.get('tool_name', '')
-    tool_input = data.get('tool_input', {})
-    session_id = data.get('session_id', 'unknown')
-    cwd = data.get('cwd', '')
-    project_name = Path(cwd).name if cwd else 'Unknown'
 
-    # Only process AskUserQuestion tool
-    if tool_name != 'AskUserQuestion':
+    # AskUserQuestion is handled by permission_request hook to avoid double input
+    if tool_name == 'AskUserQuestion':
+        log_debug("PreToolUse: Skipping AskUserQuestion (handled by permission_request)")
         return 0
 
-    log_debug(f"PreToolUse: AskUserQuestion detected")
-
-    # Extract questions from tool_input
-    questions = tool_input.get('questions', [])
-    if not questions:
-        log_debug("No questions found in AskUserQuestion input")
-        return 0
-
-    # For now, handle first question (most common case)
-    # TODO: Support multiple questions if needed
-    first_q = questions[0]
-    question_text = first_q.get('question', 'Question')
-    options = first_q.get('options', [])
-    multi_select = first_q.get('multiSelect', False)
-
-    # Convert options to relay format
-    question_options = []
-    for opt in options:
-        question_options.append({
-            'id': opt.get('label', '').lower().replace(' ', '_'),
-            'label': opt.get('label', '?'),
-            'description': opt.get('description', '')
-        })
-
-    log_debug(f"Sending question with {len(question_options)} options: {question_text[:50]}...")
-
-    # Generate notification ID for response correlation
-    notification_id = str(uuid.uuid4())
-
-    # Send directly to relay with options (bypasses CLI)
-    success = send_question_to_relay(
-        message=question_text,
-        session_id=session_id,
-        question_options=question_options,
-        multi_select=multi_select,
-        notification_id=notification_id
-    )
-
-    if success:
-        # Launch background responder to poll for Watch answer and inject keystroke
-        # This returns immediately - hook doesn't block!
-        auth_token = get_auth_token()
-        if auth_token:
-            launch_background_responder(
-                auth_token=auth_token,
-                notification_id=notification_id,
-                options=options,  # Original options list for label mapping
-                timeout=55
-            )
-
+    # No other tools need pre_tool_use handling currently
     return 0
 
 
